
"""HTTP form parser that supports file uploads, Unicode, and various suffixes.
"""

from zope.httpform.parser import FormParser, parse

__all__ = ('FormParser', 'parse')
